@@ -234,8 +234,7 @@ numout*getMEcode(int twidth,int Gauge, char*Process, char*excludeVirtual,
    if(twidth) strcat(lib_,"_t");  
    for(test=allProc;test; test=test->next) if(strcmp(lib_,test->libname)==0) 
    {
-     *(test->cc->interface->gtwidth)=0;
-     *(test->cc->interface->twidth) =0;
+     *(test->cc->interface->twidth) =twidth;
      *(test->cc->interface->gswidth)=0;
      *(test->cc->interface->BWrange)=BWrange; 
      free(lib_);
@@ -312,6 +311,7 @@ numout*getMEcode(int twidth,int Gauge, char*Process, char*excludeVirtual,
       test->cc=cc;
    } else if(new) dClose(handle);  
     free(command); free(proclibf); free(lib_);
+    if(cc) *(cc->interface->twidth) =twidth;
     return cc; 
 }
 
