@@ -817,6 +817,22 @@ void setQforParticle(REAL *Q,char*pname)
   }
 } 
 
+static void sortWidthTxtList(txtList L)
+{
+  for(;;)
+  {
+    txtList l=L;
+    for(l=L; l && l->next; l=l->next)
+    { double n1,n2;
+      sscanf(l->txt,"%lf",&n1);
+      sscanf(l->next->txt,"%lf",&n2);
+      if(n1<n2) { char*m=l->txt; l->txt=l->next->txt; l->next->txt=m; break;} 
+    }
+    if(l->next==NULL) break;   
+  } 
+}
+
+
 
 double pWidth(char *name, txtList * LL)
 {
@@ -827,6 +843,7 @@ double pWidth(char *name, txtList * LL)
   REAL Qstat;
   REAL*Q=NULL;
 
+  if(pMass(name)==0) { if(LL) *LL=NULL; return 0;}
   for(i=0;i<nModelParticles;i++)
   { char *pnames[2]={ModelPrtcls[i].name,ModelPrtcls[i].aname};
     for(j=0;j<2;j++) if(strcmp(name,pnames[j])==0) 
@@ -874,6 +891,7 @@ double pWidth(char *name, txtList * LL)
              }    
              L=l;
            }
+           sortWidthTxtList(L);
            if(pdg0==pdg) 
            {  decayTable[i0].pdList[j0]=L; 
               if(strcmp(ModelPrtcls[i0].name,ModelPrtcls[i0].aname))
@@ -895,7 +913,8 @@ double pWidth(char *name, txtList * LL)
   width=decay22List(name,&L);
 
   if(L) 
-  {
+  { 
+    sortWidthTxtList(L);
     if(LL) *LL=L;
     decayTable[i0].pdList[j0]=L;
     if(strcmp(ModelPrtcls[i0].name,ModelPrtcls[i0].aname)) 
@@ -942,6 +961,7 @@ double pWidth(char *name, txtList * LL)
     sscanf(L->txt,"%lf %[^\n]",&width,buff);
     sprintf(L->txt,"%E %s",width/sum,buff);  
   }   
+  sortWidthTxtList(Lout);
   if(LL) *LL=Lout;
   decayTable[i0].pdList[j0]=Lout;
   if(strcmp(ModelPrtcls[i0].name,ModelPrtcls[i0].aname)) 
