@@ -76,7 +76,6 @@ int fillCutArray(void)
       case '%': aux=0; break;
       default : goto errorExit;
     }  
-                                      
 /*================ MIN bound ============*/
     strcpy(fieldName,"Wrong field 'Min. bound'");
     minOn= strlen(minStr);
@@ -93,7 +92,7 @@ int fillCutArray(void)
 
 /* =========== fill array ==========*/
 
-    if(minOn||maxOn)
+    if((minOn||maxOn)&&aux!=0)
     {  k=addcut(aux,cutStr,minOn,maxOn,min_,max_);
        switch(k)
        { case 2: strcpy(fieldName,"Too many cuts ");         goto errorExit;
@@ -115,19 +114,20 @@ int fillCutArray(void)
 
 int rancor_(double *vmin, double *vmax, double shift, double fmult,int nn)
 {
-    static double vnew,v;
+//    static
+     double vnew,v;
 
     if(!nn) return 0;
     if(invcut_1[nn-1].aux!=1) return 0;
     if(invcut_1[nn-1].minon && invcut_1[nn-1].key[1]!='^') 
     {  v=invcut_1[nn-1].cvmin;
        vnew = (v*v - shift) * fmult;
-       if(fmult > 0) *vmin=MAX(*vmin,vnew); else *vmax=MIN(*vmax,vnew);
+       if(fmult > 0){ *vmin=MAX(*vmin,vnew);}    else *vmax=MIN(*vmax,vnew);
     }
     if (invcut_1[nn-1].maxon && invcut_1[nn-1].key[1]!='_') 
     {  v=invcut_1[nn-1].cvmax;
        vnew = (v*v - shift) * fmult;
-       if(fmult > 0) *vmax=MIN(*vmax,vnew); else *vmin=MAX(*vmin,vnew);	
+       if(fmult > 0) *vmax=MIN(*vmax,vnew); else{ *vmin=MAX(*vmin,vnew); }	
     }
     return 0;
 } /* rancor_ */
@@ -149,7 +149,6 @@ void  rancor_t(double * cosmax, double hsum , double fmult, double Ecm,
 }
 
 
-
 double  calcCutFactor(double*V)
 {  
   int i;
@@ -157,13 +156,15 @@ double  calcCutFactor(double*V)
 
   for(i=0; i<nCuts; i++)
   { physValRec* pList;
+    int first=1;     
+  
     for(pList=invcut_1[i].pLists;pList;pList=pList->next)
     {  
-       val=calcPhysVal(invcut_1[i].key[0],pList->pstr,V);
-       if(!finite(val)) continue;
+       val=calcPhysVal(invcut_1[i].key[0],pList->pstr,V);     
+       if(!isfinite(val)) continue;
        switch(invcut_1[i].key[1])
-       { case '^': if(i){ if(val>valM) valM=val;}  else valM=val; break;
-         case '_': if(i){ if(val<valM) valM=val;}  else valM=val; break;
+       { case '^': if(first) valM=val; else  if(val>valM) valM=val; break;
+         case '_': if(first) valM=val; else  if(val<valM) valM=val; break;
          default:
          if(invcut_1[i].aux==1)
          {
@@ -181,8 +182,10 @@ double  calcCutFactor(double*V)
            else if(val <= invcut_1[i].cvmax) return 0;
          }                      
        }
+       first=0;
     }
-    if(invcut_1[i].key[1])
+    
+    if(invcut_1[i].key[1]=='^' || invcut_1[i].key[1]=='_' )
     {  if(invcut_1[i].aux==1)   
        {
          if ( invcut_1[i].minon && (valM < invcut_1[i].cvmin)) return 0;
