@@ -93,7 +93,7 @@ static int w_widths(FILE *mode)
                 "t-channel widths %d\n"
                 "GI trick in s-  %d\n"
                 "GI trick in t-  %d",
-           *BWrange_int,*twidth_int,*gswidth_int,*gtwidth_int);
+           *BWrange_int,*twidth_int,*gswidth_int,1);
    return 0;             
 }
 
@@ -101,8 +101,8 @@ static int r_widths(FILE *mode)
 {    fscanf(mode,"BW range    %lf\n"     
                  "t-channel widths %d\n"
                  "GI trick in s-  %d\n"                  
-                 "GI trick in t-  %d",  
-           BWrange_int,twidth_int,gswidth_int,gtwidth_int);
+                 "GI trick in t-  %*d",  
+           BWrange_int,twidth_int,gswidth_int);
 
      return 0;
 }                                   
