@@ -9,23 +9,24 @@
 #include "../../include/version.h"
 
 /*
-void  plot_Nar( char*  title, double xMin, double xMax, char*xName,  int dim, 
-               int N, double **f,double**ff,char**Y)
+void  plot_Nar( char*  title,char*xName, double xMin, double xMax, int xScale, char*yName, int N, 
+              char**Y,  int*dim, double **f,double**ff)
 */
 
 int main(int argc,char** argv)
 {   
-  char   xName[60];
+  char   xName[100];
+  char   yName[100];
   int xScale=0;   
-  char*yName=NULL; 
+  char*dataList=NULL; 
   char*buff=NULL,*procName=NULL;
   int bLen=0;
   double xMin,xMax;
   int* xDim=NULL;
+  int yDim=0;
   int xDimMax=0;
   double yMin,yMax;
-  int yDim=1;
-  int ptype=-1; 
+  int ptype=1; 
   double *f=NULL, *df=NULL;
   FILE*F;
     
@@ -75,7 +76,7 @@ int main(int argc,char** argv)
                                          while(ch) { xDim=realloc(xDim,(n+1)*sizeof(int)); sscanf(ch,"%d",xDim+n); ch=strtok(NULL," ");
                                          if(xDim[n]>xDimMax) xDimMax=xDim[n]; n++;  }
                                         } 
-      else if(strcmp(word,"yDim")==0)   sscanf(buff+1,"%*s %d",&yDim);    
+      else if(strcmp(word,"yDim")==0)   sscanf(buff+1,"%*s %d",&yDim);
       else if(strcmp(word,"title")==0)  
       { for(i=strlen(buff);buff[i-1]==' '; i--) buff[i-1]=0;
         procName=malloc(strlen(buff));
@@ -84,11 +85,18 @@ int main(int argc,char** argv)
       else if(strcmp(word,"xName")==0) 
       { for(i=strlen(buff);buff[i-1]==' '; i--) buff[i-1]=0;
         sscanf(buff+1,"%*s %[^\n]",xName);  
-      }   
+      } 
       else if(strcmp(word,"yName")==0) 
       { for(i=strlen(buff);buff[i-1]==' '; i--) buff[i-1]=0;
-        yName=malloc(strlen(buff));    
-        if(1!=sscanf(buff+1,"%*s %[^\n]",yName)) yName[0]=0;  
+        sscanf(buff+1,"%*s %[^\n]",yName);  
+      } 
+        
+      else if(strcmp(word,"dataList")==0) 
+      { 
+        for(i=strlen(buff);buff[i-1]==' '; i--) buff[i-1]=0;
+        dataList=malloc(strlen(buff));    
+        if(1!=sscanf(buff+1,"%*s %[^\n]",dataList)) dataList[0]=0;  
+//        printf("dataList =>%s\n",dataList);
       }
     } else break;
   }  
@@ -96,33 +104,32 @@ int main(int argc,char** argv)
   if(bLen<100) buff=realloc(buff,100); 
   if(!procName)  procName=" ";
   
-  if(yDim==1)
+  if(ptype==1)
   {
-    char *ch=yName;
+    char *ch=dataList;
     int N=0;
     
-    for(ch=yName; ch=strstr(ch,"{c}"); ch+=3) N++;
-    for(ch=yName; ch=strstr(ch,"{h}"); ch+=3) N++;  
+    for(ch=dataList; ch=strstr(ch,"{c}"); ch+=3) N++;
+    for(ch=dataList; ch=strstr(ch,"{h}"); ch+=3) N++;  
     if(N)
     {  double **fn=malloc(N*sizeof(double*));
        double **dn=malloc(N*sizeof(double*));
        char**Y    =malloc(N*sizeof(char*)); 
-       for(n=0,ch=yName;n<N;n++)
+       for(n=0,ch=dataList;n<N;n++)
        {  char*chc=strstr(ch,"{c}");
           char*chh=strstr(ch,"{h}");  
           Y[n]=malloc(50);
           fn[n]=malloc(xDimMax*sizeof(double));
           if(chc && (  chc<chh || !chh )) 
           { chc[0]=0;
-            sscanf(ch,"%s",Y[n]);
             dn[n]=NULL;
-            ch=chc+3;
           } else
           { chh[0]=0;
-            sscanf(ch,"%s",Y[n]);
-            dn[n]=malloc(xDimMax*sizeof(double));
-            ch=chh+3; 
+            dn[n]=malloc(xDimMax*sizeof(double)); 
           }
+          Y[n]=malloc(strlen(ch)+1);
+          strcpy(Y[n],ch);
+          ch=chc+3; 
        }
        for(i=0;i<xDimMax;i++) for(n=0;n<N;n++)
        { fscanf(F,"%lf",fn[n]+i); 
@@ -134,9 +141,9 @@ int main(int argc,char** argv)
        }
        fclose(F);     
        sprintf(icon_name,"%s/include/icon",pathtocalchep);
-       start1(VERSION_ ,icon_name,"calchep.ini;../calchep.ini",NULL);
+       start1(procName, icon_name,"calchep.ini;../calchep.ini",NULL);
        clearTypeAhead();
-       plot_Nar(argv[1],procName,xMin,xMax,xName,xScale,N,xDim,fn,dn,Y);
+       plot_Nar(argv[1],"",xName,xMin,xMax,xScale,yName,N,Y,xDim,fn,dn);
        finish();
        return 0; 
     }
@@ -144,19 +151,17 @@ int main(int argc,char** argv)
   }
   
   f=(double*)malloc(xDim[0]*yDim*sizeof(double));   
-  if(ptype)
+  if(dataList==NULL || strstr(dataList,"{h}")==0)
   { 
-    df=(double*)malloc(xDim[0]*yDim*sizeof(double)); 
-    sscanf(buff,"%lf  %lf",f,df);  
-    for(i=1;i<xDim[0]*yDim;i++) fscanf(F,"%lf  %lf",f+i,df+i);
-    for(i=1;i<xDim[0]*yDim;i++) if( !isfinite(f[i])|| !isfinite(df[i]) )
-       { printf(" NAN in table %s\n",procName); return 0;}
+    for(i=0;i<xDim[0]*yDim;i++) fscanf(F,"%lf",f+i);
+    for(i=0;i<xDim[0]*yDim;i++) if( !isfinite(f[i])){ printf(" NAN in table %s\n",procName); return 0;} 
   }
   else 
   { 
-    sscanf(buff,"%lf",f);
-    for(i=1;i<xDim[0]*yDim;i++) fscanf(F,"%lf",f+i);
-    for(i=1;i<xDim[0]*yDim;i++) if( !isfinite(f[i])){ printf(" NAN in table %s\n",procName); return 0;} 
+    df=(double*)malloc(xDim[0]*yDim*sizeof(double)); 
+    for(i=0;i<xDim[0]*yDim;i++) fscanf(F,"%lf  %lf",f+i,df+i);
+    for(i=0;i<xDim[0]*yDim;i++) if( !isfinite(f[i])|| !isfinite(df[i]) )
+       { printf(" NAN in table %s\n",procName); return 0;}
   }             
   sprintf(icon_name,"%s/include/icon",pathtocalchep);
   start1(VERSION_ ,icon_name,"calchep.ini;../calchep.ini",NULL);  
