@@ -279,7 +279,7 @@ int nden_t2=nden_t, nden_s2=nden_s;
           else  writeF("conj(Q1[%d]))",numm);
         } else
         { 
-          writeF("*(gtwidth_ext? creal(Q1[%d]):",numm);
+          writeF("*(gswidth_ext? creal(Q1[%d]):",numm);
           if (dendescript->denarr[i].power==1) writeF("Q1[%d])",numm);
           else  writeF("conj(Q1[%d]))",numm);
         }        
@@ -303,7 +303,7 @@ int nden_t2=nden_t, nden_s2=nden_s;
       writeF(";\n");
       }  
       if(nden_t2) 
-      {  writeF("if(gtwidth_ext) Prop=Prop"); 
+      {  writeF("if(gswidth_ext) Prop=Prop"); 
  
         for (k = nden_s+1; k <= nden_w; k++)					  	
         { int addpr = 1;							       
@@ -401,6 +401,7 @@ static void  onediagram(deninforec* dendescript)
   
    writeF("if(!DP){C%d(C); return 0;} \n",diagrcount);
    if(nin==2) writeF("  REAL N_p1p2_=1/DP[0];\n");
+
    fortwriter("N",totnum);
    fortwriter("D",totdenum);
    fortwriter("R",rnum);
@@ -441,6 +442,7 @@ static int  alldiagrams(FILE * fd,  int nsub)
    pos_c1= ftell(outFile); writeF("%70s\n","");   
    writeF("if(!momenta){ C%d(C); return 0;}\n",nsub);
    if(nin==2) writeF("  REAL N_p1p2_=1/DP[0];\n");
+
    while(FREAD1(dendescript,fd) == 1)
    {
       fseek(catalog,dendescript.cr_pos,SEEK_SET);
@@ -1105,7 +1107,7 @@ static int c_prog_int(void)
       make_den_info();
       fprintf(outFile,"\nCalcHEP_interface interface_ext={ %d,\n\"%s\"\n,%d, %d, varName_ext,va_ext,"
           "%d, %d, %d, &pinf_ext, &pinfAux_ext, polarized_ext, &calcFunc_ext, &BWrange_ext,&twidth_ext,"
-          "&gtwidth_ext,&gswidth_ext, &aWidth_ext, &sqme_ext,&den_info_ext,cb_ext};\n", 
+          "&gswidth_ext, &aWidth_ext, &sqme_ext,&den_info_ext,cb_ext};\n", 
       forceUG, pathtocalchep,nvars, nfunc, nin,nout,subproc_sq);
 
       writeF("\nCalcHEP_interface * PtrInterface_ext=&interface_ext;\n");
