@@ -117,6 +117,7 @@ int initvararray(int nsub, char key, polyvars * vardef_ext)
      } 
      vararr[k].used = 1;
    }
+   
    k=nmodelvar+4;
     switch(key)
     { case 'R':
@@ -125,6 +126,18 @@ int initvararray(int nsub, char key, polyvars * vardef_ext)
       case 'c': sprintf( vararr[k].alias, "N_p1p2_"      );  break;
     }                                      
     vararr[k].used = 1;                                      
+
+   for(i=1;i<=2;i++) for(j=1;j<=2;j++)
+   { 
+      k=nmodelvar+5+ 2*(i-1)+j-1;
+      switch(key)
+      { case 'R':
+        case 'F':
+        case 'M': 
+        case 'c': sprintf( vararr[k].alias, "N_pol_%d%d_"  , i,j ); break;
+      } 
+      vararr[k].used = 1;
+   }
       
    nvar=0; nfunc=0;
    
