@@ -2,6 +2,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <sys/wait.h>
+#include <signal.h>
 
 #include "chep_crt.h"
 #include "syst2.h"
@@ -49,7 +50,7 @@ static  int checkAuxDir( int nmod)
    if(i!=5)
    { 
      int dirStat=checkDir("results");
-     if(dirStat)
+     if(dirStat && blind==0)
      {  messanykey( 10,10,"There are files in directory 'results/'.\n"  
                           "To continue you has to clean or rename this directory.");
         viewresults();
@@ -59,6 +60,7 @@ static  int checkAuxDir( int nmod)
      system("if(test -d results/aux) then\n"
             "rm  -r results/aux\n"
             "fi\n"
+            "rm -f results/* \n"
             "mkdir results/aux; cd results/aux;\n"
             " mkdir models tmp results so_generated");
      for(i=0;i<5;i++)
