@@ -9,6 +9,7 @@
 #include "physics.h"
 #include "sos.h"
 #include "c_out.h"      /* consLow */
+#include "out_serv.h"
 #include "prepdiag.h"   /* longDouble */
 #include "process.h"
 #include "cweight.h"
@@ -32,7 +33,8 @@ static void init_safe(int * exitlevel)
    n_model = 1;
    newCodes=0;
    *exitlevel = 0;
-   nPROCSS=sysconf(_SC_NPROCESSORS_ONLN);
+   char * nPROCSSch=getenv("nParProc");
+   if(!nPROCSSch || 1!=sscanf(nPROCSSch,"%d",&nPROCSS)) nPROCSS=sysconf(_SC_NPROCESSORS_ONLN);
 }
 
 void restoreent(int * exitlevel)
