@@ -183,12 +183,13 @@ int  main(int argc,char** argv)
     fprintf(stdout,"\n");
       
 
-//   fprintf(stdout,"#type 1  %%1d-histogram\n");
+   fprintf(stdout,"#type 1  %%1d-histogram\n");
    fprintf(stdout,"#xName %s\n",argv[1]);
    fprintf(stdout,"#xMin %E\n",minX);
    fprintf(stdout,"#xMax %E\n",maxX);
    fprintf(stdout,"#xDim %d\n",nbin);
-   fprintf(stdout,"#yName %s {h}\n",yname);
+   fprintf(stdout,"#yName %s\n",yname);
+   fprintf(stdout,"#dataList {h}\n");
    fprintf(stdout,"#lost_momenta_max/Etot %.1E %.1E %.1E %.1E\n",pmiss[0],pmiss[1],pmiss[2],pmiss[3]); 
    fprintf(stdout,"#lost_internal_momenta_max/M %.1E %.1E %.1E %.1E\n",qmiss[3],qmiss[0],qmiss[1],qmiss[2]);
   }
