@@ -18,16 +18,17 @@ extern const int nvar_ext;
 extern const int nfunc_ext;
 
 extern char * pinf_ext(int nsub,int nprtcl,REAL* pmass,int*num);
-extern int   pinfAux_ext(int nsub, int nprtcl,int *spin2, int* color,int*neutral);
+extern int   pinfAux_ext(int nsub, int nprtcl,int *spin2, int* color,int*neutral,int*ndf);
 extern char * varName_ext[];
 
 extern double sqme_ext(int nsub,double GG, REAL * momenta, REAL*cb_coeff,int * err);
 extern int calcFunc_ext(void);
 extern double BWrange_ext;
-extern int twidth_ext, gtwidth_ext, gswidth_ext;
+extern int twidth_ext, gswidth_ext;
 extern double (*aWidth_ext)(char *);
 extern REAL va_ext[];
 
+
 extern  char * den_info_ext(int nsub, int n, int * mass, int * width,int *pnum);
 
 
@@ -54,12 +55,11 @@ typedef struct CalcHEP_interface
   int nout;
   int nprc;
   char* (*pinf)(int, int , REAL*,int *);
-  int  (*pinfAux)(int, int,int *,int*,int*);
+  int  (*pinfAux)(int, int,int *,int*,int*,int*);
   char** polarized;
   int (*calcFunc)(void);
   double * BWrange;
   int    * twidth;    
-  int *   gtwidth;
   int *   gswidth;
   double (**aWidth)(char *);
 
